get_default_postgres_pool

Function get_default_postgres_pool 

pub async fn get_default_postgres_pool() -> Option<Pool<Postgres>>
Create a postgres connection pool object, create a table to store secrets and flow statuses and perform migration. The tables are flows and secrets respectively. An environment variable named FLOWMIUM_POSTGRES_URL with value as an URL to a postgres database is expected to be set.