pub enum ExecutorError {
UnableToSpawnTask(Error),
UnableToConnectToKubernetes(Error),
UnexpectedRunnerState(i32, i32),
UnableToConstructPlan(PlannerError),
UnableToCreateFlowOrMarkTask(SchedulerError),
UnableToFetchSecret(SecretsCrudError),
FlowNameTooLong(String),
UnknownTaskStatus(i32, i32, String),
}Expand description
Errors while trying to run a task.
Variants
UnableToSpawnTask(Error)
Unable to deploy a job on Kubernetes.
UnableToConnectToKubernetes(Error)
Unable to connect to Kubernetes API.
UnexpectedRunnerState(i32, i32)
A pod unexpectedly disappeared or duplicate pods found for a single tasks or cannot fetch details for a pod corresponding to a task.
UnableToConstructPlan(PlannerError)
Unable to construct a plan because of errors in the flow definition.
UnableToCreateFlowOrMarkTask(SchedulerError)
Unable to talk to the scheduler, probably an issue with talking to the database.
UnableToFetchSecret(SecretsCrudError)
Unable to fetch secrets from the database.
FlowNameTooLong(String)
Name of the flow exceeds 32 characters.
UnknownTaskStatus(i32, i32, String)
Kubernetes returned an unknown status for a pod corresponding to a task.