pub async fn instantiate_flow(
flow: Flow,
sched: &Scheduler,
) -> Result<i32, ExecutorError>Expand description
Create a workflow in pending state that will start running eventually by calling crate::executor::schedule_and_run_tasks.
pub async fn instantiate_flow(
flow: Flow,
sched: &Scheduler,
) -> Result<i32, ExecutorError>Create a workflow in pending state that will start running eventually by calling crate::executor::schedule_and_run_tasks.