FlowRecord

Struct FlowRecord 

pub struct FlowRecord {
    pub id: i32,
    pub flow_name: String,
    pub status: FlowStatus,
    pub plan: Value,
    pub current_stage: i32,
    pub running_tasks: Vec<i32>,
    pub finished_tasks: Vec<i32>,
    pub failed_tasks: Vec<i32>,
    pub task_definitions: Value,
}
Detailed status of a flow.

Fields

id: i32

Unique identifier for the flow.

flow_name: String

Name of the flow as specified in crate::model::Flow.

status: FlowStatus

Status of the flow.

plan: Value

Execution plan of the flow. This is a nested 2D JSON array containing integer elements. The integer elements refer to index of a task defined in crate::model::Flow. A task is executed in multiple stages, where each stage is a set of tasks. The set of tasks in the last stage are dependent set of tasks in the last but second stage and so on, with the first stage having tasks that are independent having no dependencies (leaf tasks). Tasks belonging to the same stage are not dependent on each other, if a task is dependent on another task, they will belong to different stages.

current_stage: i32

Current stage that is running. Set of tasks in the same stage are spawned at the same time because they are not dependent on each other.

running_tasks: Vec<i32>

Indices of tasks that are currently running.

finished_tasks: Vec<i32>

Indices of tasks that have finished.

failed_tasks: Vec<i32>

Indices of tasks that have failed.

task_definitions: Value

List of tasks that belong to this flow, as define in crate::model::Flow.